Web services
============

Django-oscar exposes three different RESTful webservices for administration:

.. toctree::
   :maxdepth: 2

   web_services/order_management
   web_services/stock_management
   web_services/inventory_management

